# Generated by Django 4.2.23 on 2025-10-22 11:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("custom_fields", "0003_add_type_filter_to_fields"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="customfield",
            name="multiple_choice",
        ),
    ]
