# Generated by Django 4.2.23 on 2025-10-22 12:04

from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    dependencies = [
        ("custom_fields", "0004_remove_mutiple_choice_field"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="customvalue",
            name="text",
        ),
        migrations.RemoveField(
            model_name="customvalue",
            name="text_de",
        ),
        migrations.RemoveField(
            model_name="customvalue",
            name="text_en",
        ),
        migrations.RemoveField(
            model_name="customvalue",
            name="text_fr",
        ),
        migrations.AddField(
            model_name="customvalue",
            name="label",
            field=models.CharField(blank=True, null=True, verbose_name="Label"),
        ),
        migrations.AddField(
            model_name="customvalue",
            name="label_de",
            field=models.CharField(blank=True, null=True, verbose_name="Label"),
        ),
        migrations.AddField(
            model_name="customvalue",
            name="label_en",
            field=models.CharField(blank=True, null=True, verbose_name="Label"),
        ),
        migrations.AddField(
            model_name="customvalue",
            name="label_fr",
            field=models.CharField(blank=True, null=True, verbose_name="Label"),
        ),
    ]
