# Generated by Django 4.2.23 on 2025-09-04 07:42

from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    dependencies = [
        ("system_message", "0002_create_default_system_message_types"),
    ]

    operations = [
        migrations.AlterField(
            model_name="systemmessage",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="systemmessagetype",
            name="icon",
            field=models.CharField(
                blank=True,
                help_text="Icon Name von mdi ohne mdi-Prefix mit Bindestrich getrennt",
                max_length=255,
                null=True,
                verbose_name="Icon",
            ),
        ),
        migrations.AlterField(
            model_name="systemmessagetype",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
