# Generated by Django 4.2.23 on 2025-10-03 09:29

from django.conf import settings
from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("system_message", "0003_alter_id_fields_with_big_auto_field"),
    ]

    operations = [
        migrations.AlterField(
            model_name="systemmessage",
            name="dismissed_users",
            field=models.ManyToManyField(
                blank=True,
                related_name="dismissed_system_messages",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
